;; Generated package description from org.el
(define-package "org" "9.1.14" "Outline-based notes management and organizer" 'nil :url "http://elpa.gnu.org/packages/org.html" :keywords '("outlines" "hypermedia" "calendar" "wp"))
